########
Glossary
########


************
Great circle
************

In mathematics, a great circle or orthodrome is the circular intersection of a sphere and a plane passing through the sphere's center point.

****
DGGS
****

A discrete global grid (DGG) is a mosaic that covers the entire Earth's surface. Mathematically it is a space partitioning: it consists of a set of non-empty regions that form a partition of the Earth's surface. In a usual grid-modeling strategy, to simplify position calculations, each region is represented by a point, abstracting the grid as a set of region-points. Each region or region-point in the grid is called a cell.

****
TIN
****

In computer graphics, a triangulated irregular network (TIN) is a representation of a continuous surface consisting entirely of triangular facets (a triangle mesh), used mainly as Discrete Global Grid in primary elevation modeling.

****
MPAS
****

Model for Prediction Across Scales.